
From: Michael Krufky <mike@krufky.com>

Even though it says DViCO FusionHDTV3 Gold-Q on the box, Gold-T is printed
on the card.  This fix corrects the error in all places, and corrects the
tuner name Thomson DDT 7611 (ATSC/NTSC) in the documentation.

This applies against 2.6.12-rc5-mm2 after applying Manueal Capinha's 
patch "Add support for PixelView Ultra Pro in v4l" (because of the 
change from card=27 to card=28)

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 Documentation/video4linux/CARDLIST.cx88  |    2 +-
 Documentation/video4linux/CARDLIST.tuner |    2 +-
 drivers/media/video/cx88/cx88-cards.c    |   23 ++++++-----------------
 drivers/media/video/cx88/cx88.h          |    2 +-
 4 files changed, 9 insertions(+), 20 deletions(-)

diff -puN Documentation/video4linux/CARDLIST.cx88~dvico-fusionhdtv3-gold-t-documentation-fix Documentation/video4linux/CARDLIST.cx88
--- 25/Documentation/video4linux/CARDLIST.cx88~dvico-fusionhdtv3-gold-t-documentation-fix	2005-06-07 20:45:04.000000000 -0700
+++ 25-akpm/Documentation/video4linux/CARDLIST.cx88	2005-06-07 20:45:04.000000000 -0700
@@ -26,4 +26,4 @@ card=24 - Hauppauge WinTV 28xxx (Roslyn)
 card=25 - Digital-Logic MICROSPACE Entertainment Center (MEC)
 card=26 - IODATA GV/BCTV7E
 card=27 - PixelView PlayTV Ultra Pro (Stereo)
-card=28 - DViCO - FusionHDTV 3 Gold-Q
+card=28 - DViCO - FusionHDTV 3 Gold-T
diff -puN Documentation/video4linux/CARDLIST.tuner~dvico-fusionhdtv3-gold-t-documentation-fix Documentation/video4linux/CARDLIST.tuner
--- 25/Documentation/video4linux/CARDLIST.tuner~dvico-fusionhdtv3-gold-t-documentation-fix	2005-06-07 20:45:04.000000000 -0700
+++ 25-akpm/Documentation/video4linux/CARDLIST.tuner	2005-06-07 20:45:04.000000000 -0700
@@ -58,4 +58,4 @@ tuner=56 - Philips PAL/SECAM multi (FQ12
 tuner=57 - Philips FQ1236A MK4
 tuner=58 - Ymec TVision TVF-8531MF
 tuner=59 - Ymec TVision TVF-5533MF
-tuner=60 - Thomson DDT 7611
+tuner=60 - Thomson DDT 7611 (ATSC/NTSC)
diff -puN drivers/media/video/cx88/cx88-cards.c~dvico-fusionhdtv3-gold-t-documentation-fix drivers/media/video/cx88/cx88-cards.c
--- 25/drivers/media/video/cx88/cx88-cards.c~dvico-fusionhdtv3-gold-t-documentation-fix	2005-06-07 20:45:04.000000000 -0700
+++ 25-akpm/drivers/media/video/cx88/cx88-cards.c	2005-06-07 20:45:04.000000000 -0700
@@ -428,16 +428,11 @@ struct cx88_board cx88_boards[] = {
 			.vmux   = 2,
 			.gpio0	= 0x0f00,
 		}},
-#if 0
-		.ts             = {
-			 .type   = CX88_TS,
-			 .gpio0  = 0x00000f01,   /* Hooked to tuner reset bit */
-		 }
-#endif
-	},
-        [CX88_BOARD_DVICO_FUSIONHDTV_3_GOLD_Q] = {
-                .name           = "DViCO - FusionHDTV 3 Gold-Q",
-                .tuner_type     = 52, /* Thomson DDT 7610 ATSC/NTSC - Its actually a 7611 chip, but this works */
+	},
+        [CX88_BOARD_DVICO_FUSIONHDTV_3_GOLD_T] = {
+                .name           = "DViCO - FusionHDTV 3 Gold-T",
+                .tuner_type     = 52, /* Thomson DDT 7611 ATSC/NTSC */
+               /*  See DViCO FusionHDTV 3 Gold for GPIO documentation.  */
                 .input          = {{
                         .type   = CX88_VMUX_TELEVISION,
                         .vmux   = 0,
@@ -455,12 +450,6 @@ struct cx88_board cx88_boards[] = {
                         .vmux   = 2,
                         .gpio0  = 0x0f00,
                 }},
-#if 0
-                .ts             = {
-                         .type   = CX88_TS,
-                         .gpio0  = 0x00000f01,   /* Hooked to tuner reset bit */
-                 }
-#endif
         },
         [CX88_BOARD_HAUPPAUGE_DVB_T1] = {
                 .name           = "Hauppauge Nova-T DVB-T",
@@ -723,7 +712,7 @@ struct cx88_subid cx88_subids[] = {
 	},{
 		.subvendor = 0x18ac,
 		.subdevice = 0xd820,
-		.card      = CX88_BOARD_DVICO_FUSIONHDTV_3_GOLD_Q,
+		.card      = CX88_BOARD_DVICO_FUSIONHDTV_3_GOLD_T,
 	},{
 		.subvendor = 0x18AC,
 		.subdevice = 0xDB00,
diff -puN drivers/media/video/cx88/cx88.h~dvico-fusionhdtv3-gold-t-documentation-fix drivers/media/video/cx88/cx88.h
--- 25/drivers/media/video/cx88/cx88.h~dvico-fusionhdtv3-gold-t-documentation-fix	2005-06-07 20:45:04.000000000 -0700
+++ 25-akpm/drivers/media/video/cx88/cx88.h	2005-06-07 20:45:04.000000000 -0700
@@ -163,7 +163,7 @@ extern struct sram_channel cx88_sram_cha
 #define CX88_BOARD_DIGITALLOGIC_MEC	       25
 #define CX88_BOARD_IODATA_GVBCTV7E         26
 #define CX88_BOARD_PIXELVIEW_PLAYTV_ULTRA_PRO 27
-#define CX88_BOARD_DVICO_FUSIONHDTV_3_GOLD_Q   28
+#define CX88_BOARD_DVICO_FUSIONHDTV_3_GOLD_T   28
 
 enum cx88_itype {
 	CX88_VMUX_COMPOSITE1 = 1,
_
